==> recruit-drop-list-1.0.22.tgz: package/src/textbox.js <==
 /* eslint-disable */
import React, {Component} from 'react'
import { render } from 'react-dom';
import debounce from 'es6-promise-debounce'
import ToolTip from "@beisen-platform/ethos/lib/ToolTip"
import CommonLabel from '@beisen-platform/ethos/lib/CommonLabel'
import CommonInput from '@beisen/common-input'

export default class Textbox extends Component {
    static defaultProps = {
      hasClosebtn: true
    }
  constructor(props) {
    super(props);
    this.state = {
      defaultValue: props.defaultValue,
      hoverFocusing: false,
      clickFocusing: false,
      pointerEvent: "auto",
      showHiddenTips: 'block',
      mouseTips: false
    }

    this.clearData = this.clearData.bind(this);
    this.handlerFocus = this.handlerFocus.bind(this);
    this.handlerBlur = this.handlerBlur.bind(this);
    this.handlerClick = this.handlerClick.bind(this);
    this.handlerOver = this.handlerOver.bind(this);
    this.handlerOut = this.handlerOut.bind(this);
    this.onRealChange = this.onRealChange.bind(this);
    this.handlerChange = debounce(this.handlerChange,300)
  }
  componentWillReceiveProps(nextProps) {
    if (nextProps.defaultValue != this.state.defaultValue) {
      this.setState({
        defaultValue: nextProps.defaultValue
      });
      if (this.refs.baseInput) {
        this.refs.baseInput.value = nextProps.defaultValue;
      }
    }
  }

  /*获得焦点*/
  handlerFocus(event) {
    this.callBackValue(event,"onFocus");
    this.clearToolTipDom();
    if(!this.props.readonly) {
      this.setState({clickFocusing: true});
      if (this.refs.baseInput.value !== "") {
        this.setState({hoverFocusing: true})
      }
    }
  }
  handlerChange(event) {
    if (this.props.readonly || this.props.disabled) {
      return;
    }
    this.callBackValue(event,"onChange");
    this.setState({defaultValue: this.refs.baseInput.value});
  }
  handlerClick(event) {
    this.callBackValue(event,"onClick");
  }
  handlerBlur(event) {
    if (this.props.readonly || this.props.disabled) {
      return;
    }
    this.callBackValue(event,"onBlur");
    let self = this;
    setTimeout(() => {
      self.setState({hoverFocusing: false, clickFocusing: false, pointerEvent: 'auto', showHiddenTips: 'block'});
    },300)
  }
  handlerOver(event) {
    if (this.props.readonly || this.props.disabled) {
      return;
    }
    if (this.state.clickFocusing) {
      return;
    } else if(this.refs.baseInput.value !== "") {
      this.setState({
        hoverFocusing: true
      });
    }
  }
  handlerOut(event) {
    if (this.props.readonly || this.props.disabled) {
      return;
    }
    // let dom  (this.refs.mouseIconClose);
    // if (dom.className.indexOf('active') > 0) {
    //   return;
    // } else {
      this.setState({
        mouseTips: false,
        hoverFocusing: false
      })
      this.clearToolTipDom();
    // }
  }

  clearToolTipDom() {
    let dom_1 = document.getElementsByClassName('tooltip')[0];
    let dom_2 = document.getElementsByClassName('tooltip-arrow')[0];
    if (dom_1 && dom_2) {
      let parNode = dom_1.parentNode;
      parNode.removeChild(dom_1);
      parNode.removeChild(dom_2);
    }
  }

  callBackValue(event,status) {
    if(this.props.disabled) return false;
    this.props[status] && this.props[status](event, status, this.refs.baseInput.value)
  }

  clearData(event) {
    if (this.props.readonly || this.props.disabled) {
      return;
    }
    this.props.onBlur && this.props.onBlur(event, "onBlur", "");
    this.props.onChange && this.props.onChange(event, "onChange", "");
    this.refs.baseInput.value = "";
  }
  clearDown(event) {
    event.preventDefault();
  }

  onRealChange(event) {
    event.persist();
    this.handlerChange(event);
  }

  tipsClick = () => {
    this.setState({pointerEvent: "none", clickFocusing: true, showHiddenTips: 'none'})
    this.refs.baseInput.focus()
  }

  onMouseTip = () => {
    let self =this;
    //解决点击输入框时光标错位，引起原因是输入框上有层div导致
    setTimeout(()=> {
      self.setState({mouseTips:true})
    },100)
  }

  render() {
    const {clickFocusing, defaultValue, pointerEvent, hoverFocusing, showHiddenTips, mouseTips} = this.state;
    const {errorStatus, errorMsg, showText, hidden, hiddenTip,
      disabled, readonly, placeHolder, maxLength, hasClosebtn} = this.props;
    let inputClassName = 'u-input';
    let closeStyle = !readonly && !disabled && defaultValue && defaultValue.length>0 && (hoverFocusing || clickFocusing)  ? 
      {display: 'block', marginRight: '5px'} : {display: 'none'};  
    let _tempSymbol =  readonly ? {"height":"14px","display":"inline-block","lineHeight":"14px",'position':'absolute','top':'0','right':'20px'}:{"height":"14px","display":"inline-block","lineHeight":"14px"}
    if(defaultValue == '') {
      inputClassName = 'u-input u-input-noValue';
    }
    let inputStyle = !readonly && !disabled && defaultValue && defaultValue.length>0 && (hoverFocusing || clickFocusing) ? {'maxWidth':'calc(100% - 22px)'} : {}
    if(hidden) {
      return <div></div>;
    }else{
      return (
        <div className="form-item">
          <CommonLabel {...this.props} />
          {
            readonly || disabled
              ? <CommonInput readonly={true} errorStatus={errorStatus} errorMsg={errorMsg} defaultValue={defaultValue} />
              : <div className={"form-item__control "
                  +(clickFocusing?'form-item__control_is-active ':'')+(showText && showText.length > 0?"form-item__control_has-info ":"")
                  +(errorStatus?'form-item__control_is-active form-item__control_has-info form-item__control_has-error':'')}
                  onMouseEnter={this.handlerOver} onMouseLeave={this.handlerOut} ref="mouseIconClose"
                >
                  {
                    mouseTips
                      ? ""
                      : <ToolTip title={defaultValue} hidden={hiddenTip}>
                      <div className="form-item_is-hidden-tips" onMouseEnter={this.onMouseTip} style={{pointerEvents: pointerEvent, display: showHiddenTips}} onClick={this.tipsClick}>
                        {defaultValue}
                      </div>
                    </ToolTip>
                  }
                  <input type="text"
                    style={inputStyle}
                    className={inputClassName}
                    placeholder={placeHolder}
                    readOnly={readonly}
                    disabled={disabled}
                    onFocus={this.handlerFocus}
                    onBlur={this.handlerBlur}
                    onClick={this.handlerClick}
                    defaultValue={defaultValue}
                    onChange={this.onRealChange}
                    maxLength={maxLength}
                    ref='baseInput'
                  />
                  <span className="form-item__right-icon" onClick={this.clearData} onMouseDown={this.clearDown}>
                    {readonly ?
                      <i className="u-icon pc-sys-bukebianji-nomal-svg disabled-icon" style={{position:'absolute',right:'-1px',bottom:'-15px',width:'11px',height:'13px'}}></i>
                      :''
                    }
                    {hasClosebtn? <i className="close-icon" style={closeStyle}></i>: ''}
                    <span style={_tempSymbol}>{this.props.symbol}</span>
                  </span>
                  {(clickFocusing && showText && showText.length > 0 || errorStatus) ? <span className="form-item__explain">{errorStatus?errorMsg:showText}</span>:''}
                </div>
          }
        </div>
      )
    }
  }
}

==> recruit-drop-list-1.0.27.tgz: package/src/textbox.js <==
 /* eslint-disable */
import React, {Component} from 'react'
import { render } from 'react-dom';
import debounce from 'es6-promise-debounce'
import ToolTip from "@beisen-platform/ethos/lib/ToolTip"
import CommonLabel from '@beisen-platform/ethos/lib/CommonLabel'
import CommonInput from '@beisen-platform/common-input'

export default class Textbox extends Component {
    static defaultProps = {
      hasClosebtn: true
    }
  constructor(props) {
    super(props);
    this.state = {
      defaultValue: props.defaultValue,
      hoverFocusing: false,
      clickFocusing: false,
      pointerEvent: "auto",
      showHiddenTips: 'block',
      mouseTips: false
    }

    this.clearData = this.clearData.bind(this);
    this.handlerFocus = this.handlerFocus.bind(this);
    this.handlerBlur = this.handlerBlur.bind(this);
    this.handlerClick = this.handlerClick.bind(this);
    this.handlerOver = this.handlerOver.bind(this);
    this.handlerOut = this.handlerOut.bind(this);
    this.onRealChange = this.onRealChange.bind(this);
    this.handlerChange = debounce(this.handlerChange,300)
  }
  componentWillReceiveProps(nextProps) {
    if (nextProps.defaultValue != this.state.defaultValue) {
      this.setState({
        defaultValue: nextProps.defaultValue
      });
      if (this.refs.baseInput) {
        this.refs.baseInput.value = nextProps.defaultValue;
      }
    }
  }

  /*获得焦点*/
  handlerFocus(event) {
    this.callBackValue(event,"onFocus");
    this.clearToolTipDom();
    if(!this.props.readonly) {
      this.setState({clickFocusing: true});
      if (this.refs.baseInput.value !== "") {
        this.setState({hoverFocusing: true})
      }
    }
  }
  handlerChange(event) {
    if (this.props.readonly || this.props.disabled) {
      return;
    }
    this.callBackValue(event,"onChange");
    this.setState({defaultValue: this.refs.baseInput.value});
  }
  handlerClick(event) {
    this.callBackValue(event,"onClick");
  }
  handlerBlur(event) {
    if (this.props.readonly || this.props.disabled) {
      return;
    }
    this.callBackValue(event,"onBlur");
    let self = this;
    setTimeout(() => {
      self.setState({hoverFocusing: false, clickFocusing: false, pointerEvent: 'auto', showHiddenTips: 'block'});
    },300)
  }
  handlerOver(event) {
    if (this.props.readonly || this.props.disabled) {
      return;
    }
    if (this.state.clickFocusing) {
      return;
    } else if(this.refs.baseInput.value !== "") {
      this.setState({
        hoverFocusing: true
      });
    }
  }
  handlerOut(event) {
    if (this.props.readonly || this.props.disabled) {
      return;
    }
    // let dom  (this.refs.mouseIconClose);
    // if (dom.className.indexOf('active') > 0) {
    //   return;
    // } else {
      this.setState({
        mouseTips: false,
        hoverFocusing: false
      })
      this.clearToolTipDom();
    // }
  }

  clearToolTipDom() {
    let dom_1 = document.getElementsByClassName('tooltip')[0];
    let dom_2 = document.getElementsByClassName('tooltip-arrow')[0];
    if (dom_1 && dom_2) {
      let parNode = dom_1.parentNode;
      parNode.removeChild(dom_1);
      parNode.removeChild(dom_2);
    }
  }

  callBackValue(event,status) {
    if(this.props.disabled) return false;
    this.props[status] && this.props[status](event, status, this.refs.baseInput.value)
  }

  clearData(event) {
    if (this.props.readonly || this.props.disabled) {
      return;
    }
    this.props.onBlur && this.props.onBlur(event, "onBlur", "");
    this.props.onChange && this.props.onChange(event, "onChange", "");
    this.refs.baseInput.value = "";
  }
  clearDown(event) {
    event.preventDefault();
  }

  onRealChange(event) {
    event.persist();
    this.handlerChange(event);
  }

  tipsClick = () => {
    this.setState({pointerEvent: "none", clickFocusing: true, showHiddenTips: 'none'})
    this.refs.baseInput.focus()
  }

  onMouseTip = () => {
    let self =this;
    //解决点击输入框时光标错位，引起原因是输入框上有层div导致
    setTimeout(()=> {
      self.setState({mouseTips:true})
    },100)
  }

  render() {
    const {clickFocusing, defaultValue, pointerEvent, hoverFocusing, showHiddenTips, mouseTips} = this.state;
    const {errorStatus, errorMsg, showText, hidden, hiddenTip,
      disabled, readonly, placeHolder, maxLength, hasClosebtn} = this.props;
    let inputClassName = 'u-input';
    let closeStyle = !readonly && !disabled && defaultValue && defaultValue.length>0 && (hoverFocusing || clickFocusing)  ? 
      {display: 'block', marginRight: '5px'} : {display: 'none'};  
    let _tempSymbol =  readonly ? {"height":"14px","display":"inline-block","lineHeight":"14px",'position':'absolute','top':'0','right':'20px'}:{"height":"14px","display":"inline-block","lineHeight":"14px"}
    if(defaultValue == '') {
      inputClassName = 'u-input u-input-noValue';
    }
    let inputStyle = !readonly && !disabled && defaultValue && defaultValue.length>0 && (hoverFocusing || clickFocusing) ? {'maxWidth':'calc(100% - 22px)'} : {}
    if(hidden) {
      return <div></div>;
    }else{
      return (
        <div className="form-item">
          <CommonLabel {...this.props} />
          {
            readonly || disabled
              ? <CommonInput readonly={true} errorStatus={errorStatus} errorMsg={errorMsg} defaultValue={defaultValue} />
              : <div className={"form-item__control "
                  +(clickFocusing?'form-item__control_is-active ':'')+(showText && showText.length > 0?"form-item__control_has-info ":"")
                  +(errorStatus?'form-item__control_is-active form-item__control_has-info form-item__control_has-error':'')}
                  onMouseEnter={this.handlerOver} onMouseLeave={this.handlerOut} ref="mouseIconClose"
                >
                  {
                    mouseTips
                      ? ""
                      : <ToolTip title={defaultValue} hidden={hiddenTip}>
                      <div className="form-item_is-hidden-tips" onMouseEnter={this.onMouseTip} style={{pointerEvents: pointerEvent, display: showHiddenTips}} onClick={this.tipsClick}>
                        {defaultValue}
                      </div>
                    </ToolTip>
                  }
                  <input type="text"
                    style={inputStyle}
                    className={inputClassName}
                    placeholder={placeHolder}
                    readOnly={readonly}
                    disabled={disabled}
                    onFocus={this.handlerFocus}
                    onBlur={this.handlerBlur}
                    onClick={this.handlerClick}
                    defaultValue={defaultValue}
                    onChange={this.onRealChange}
                    maxLength={maxLength}
                    ref='baseInput'
                  />
                  <span className="form-item__right-icon" onClick={this.clearData} onMouseDown={this.clearDown}>
                    {readonly ?
                      <i className="u-icon pc-sys-bukebianji-nomal-svg disabled-icon" style={{position:'absolute',right:'-1px',bottom:'-15px',width:'11px',height:'13px'}}></i>
                      :''
                    }
                    {hasClosebtn? <i className="close-icon" style={closeStyle}></i>: ''}
                    <span style={_tempSymbol}>{this.props.symbol}</span>
                  </span>
                  {(clickFocusing && showText && showText.length > 0 || errorStatus) ? <span className="form-item__explain">{errorStatus?errorMsg:showText}</span>:''}
                </div>
          }
        </div>
      )
    }
  }
}
